local bit = require "bit"

local lua_version = function()
  local version = assert(_VERSION)
  local maj, min = version:match("^Lua (%d+)%.(%d+)$")
  return tonumber(maj)  * 100 + tonumber(min)
end

local function lshift(v, n)
  return math.floor(v * (2 ^ n))
end

local function rshift(v, n)
  return math.floor(v / (2 ^ n))
end

local function time2dos(file_ts)
  local t = os.date("*t", file_ts)

  return bit.bor(
    bit.lshift(t.year-1980, 25),
    bit.lshift(t.month,     21),
    bit.lshift(t.day,       16),
    bit.lshift(t.hour,      11),
    bit.lshift(t.min,        5),
    bit.rshift(t.sec+2,      1) -- 7z
  )
end

local function time2filetime(file_ts)
  file_ts = 10000000 * (file_ts + 11644473600)
  local high = rshift(file_ts, 32)
  local low  = file_ts - lshift(high, 32)
  return {low, high}
end

local M = {}

M.time2dos       = time2dos
M.time2filetime  = time2filetime
M.IS_WINDOWS     = false
M.LUA_VER_NUM    = lua_version()

return M
